@@ -27,7 +27,12 @@
 #define TAB_LABEL_MAP    "Map"
 #define TAB_LABEL_DIRECT "Direct"
 #define TAB_LABEL_EXTENT "Extent"
+
+/* maemo5 currently has no maemo mapper */
+#if defined(USE_HILDON) && (MAEMO_VERSION_MAJOR < 5)
+#define HAS_MAEMO_MAPPER
 #define TAB_LABEL_MM     "Maemo Mapper"
+#endif
 
 /* limit of square kilometers above the warning is enabled */
 #define WARN_OVER  5.0
@@ -41,14 +46,16 @@ typedef struct {
 
   struct {
     GtkWidget *minlat, *maxlat, *minlon, *maxlon;
+    GtkWidget *error;
   } direct;
 
   struct {
     GtkWidget *lat, *lon, *height, *width, *mil_km;
     gboolean is_mil;
+    GtkWidget *error;
   } extent;
 
-#ifdef USE_HILDON 
+#ifdef HAS_MAEMO_MAPPER
   struct {
     GtkWidget *fetch;
   } mmapper;
@@ -149,6 +156,26 @@ static void area_main_update(context_t *context) {
   pos_lon_label_set(context->minlon, context->min.lon);
   pos_lon_label_set(context->maxlon, context->max.lon);
 
+  /* also setup the local error messages here, so they are */
+  /* updated for all entries at once */
+  if(context->min.lat >= context->max.lat ||
+     context->min.lon >= context->max.lon) {
+    gtk_label_set(GTK_LABEL(context->direct.error), 
+		  _("\"From\" must be smaller than \"to\" value!")); 
+    gtk_label_set(GTK_LABEL(context->extent.error), 
+		  _("Extents must be positive!")); 
+
+    gtk_dialog_set_response_sensitive(GTK_DIALOG(context->dialog), 
+				      GTK_RESPONSE_ACCEPT, FALSE);
+
+  } else {
+    gtk_label_set(GTK_LABEL(context->direct.error), "");
+    gtk_label_set(GTK_LABEL(context->extent.error), "");
+
+    gtk_dialog_set_response_sensitive(GTK_DIALOG(context->dialog), 
+				      GTK_RESPONSE_ACCEPT, TRUE);
+  }
+
   /* check if area size exceeds recommended values */
   pos_float_t center_lat = (context->max.lat + context->min.lat)/2;
   double vscale = DEG2RAD(POS_EQ_RADIUS / 1000.0);
@@ -218,14 +245,17 @@ static void map_update(context_t *context, gboolean forced) {
     
     /* ---------- draw border (as a gps track) -------------- */  
     osm_gps_map_clear_tracks(OSM_GPS_MAP(context->map.widget));
-    
-    GSList *box = pos_append(NULL, context->min.lat, context->min.lon);
-    box = pos_append(box, context->max.lat, context->min.lon);
-    box = pos_append(box, context->max.lat, context->max.lon);
-    box = pos_append(box, context->min.lat, context->max.lon);
-    box = pos_append(box, context->min.lat, context->min.lon);
-    
-    osm_gps_map_add_track(OSM_GPS_MAP(context->map.widget), box);
+
+    if(context->max.lat > context->min.lat &&
+       context->max.lon > context->min.lon) {
+      GSList *box = pos_append(NULL, context->min.lat, context->min.lon);
+      box = pos_append(box, context->max.lat, context->min.lon);
+      box = pos_append(box, context->max.lat, context->max.lon);
+      box = pos_append(box, context->min.lat, context->max.lon);
+      box = pos_append(box, context->min.lat, context->min.lon);
+      
+      osm_gps_map_add_track(OSM_GPS_MAP(context->map.widget), box);
+    }
   }
     
   context->map.needs_redraw = FALSE;
@@ -339,7 +369,7 @@ static void callback_modified_unit(GtkWidget *widget, gpointer data) {
   pos_dist_entry_set(context->extent.height, height, context->extent.is_mil);  
 }
 
-#ifdef USE_HILDON
+#ifdef HAS_MAEMO_MAPPER
 static void callback_fetch_mm_clicked(GtkButton *button, gpointer data) {
   context_t *context = (context_t*)data;
 
@@ -514,6 +544,9 @@ cb_map_gps(osd_button_t but, context_t *context) {
     if(gps_on && gps_get_pos(context->area->appdata, &pos, NULL)) {
       osm_gps_map_set_center(OSM_GPS_MAP(context->map.widget),
 			     pos.lat, pos.lon);	    
+
+      /* re-enable centering */
+      g_object_set(context->map.widget, "auto-center", TRUE, NULL);
     }
   }
 }
@@ -536,14 +569,21 @@ static gboolean map_gps_update(gpointer data) {
     context->area->appdata->settings && 
     context->area->appdata->settings->enable_gps;
 
+  pos_t pos = { NAN, NAN }; 
   gboolean gps_fix = gps_on && 
-    gps_get_pos(context->area->appdata, NULL, NULL);
+    gps_get_pos(context->area->appdata, &pos, NULL);
 
   /* ... and enable "goto" button if it's valid */
   osm_gps_map_osd_enable_gps(OSM_GPS_MAP(context->map.widget), 
      OSM_GPS_MAP_OSD_CALLBACK(gps_fix?cb_map_gps:NULL), context);
 
-
+  if(gps_fix) {
+    g_object_set(context->map.widget, "gps-track-highlight-radius", 0, NULL);
+    osm_gps_map_draw_gps(OSM_GPS_MAP(context->map.widget), 
+			 pos.lat, pos.lon, NAN);
+  } else
+    osm_gps_map_clear_gps(OSM_GPS_MAP(context->map.widget));
+ 
   return TRUE;
 }
 
@@ -551,6 +591,8 @@ static gboolean map_gps_update(gpointer data) {
 
 gboolean area_edit(area_edit_t *area) {
   GtkWidget *vbox;
+  GdkColor color;
+  gdk_color_parse("red", &color);
 
   context_t context;
   memset(&context, 0, sizeof(context_t));
@@ -607,6 +649,7 @@ gboolean area_edit(area_edit_t *area) {
   context.map.widget = g_object_new(OSM_TYPE_GPS_MAP,
  	        "map-source", OSM_GPS_MAP_SOURCE_OPENSTREETMAP,
 		"proxy-uri", misc_get_proxy_uri(area->settings),
+		"auto-center", FALSE,
 	        "tile-cache", NULL,
 		 NULL);
 
@@ -632,7 +675,7 @@ gboolean area_edit(area_edit_t *area) {
   /* ------------ direct min/max edit --------------- */
 
   vbox = gtk_vbox_new(FALSE, 10);
-  table = gtk_table_new(3, 3, FALSE);  // x, y
+  table = gtk_table_new(3, 4, FALSE);  // x, y
   gtk_table_set_col_spacings(GTK_TABLE(table), 10);
   gtk_table_set_row_spacings(GTK_TABLE(table), 5);
 
@@ -667,6 +710,11 @@ gboolean area_edit(area_edit_t *area) {
   label = gtk_label_new(_("(recommended min/max diff <0.03 degrees)"));
   gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 3, 2, 3);
 
+  /* error label */
+  context.direct.error = gtk_label_new("");
+  gtk_widget_modify_fg(context.direct.error, GTK_STATE_NORMAL, &color);
+  gtk_table_attach_defaults(GTK_TABLE(table), context.direct.error, 0, 3, 3, 4);
+
   gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 0);
   gtk_notebook_append_page(GTK_NOTEBOOK(context.notebook),
 	   vbox, gtk_label_new(_(TAB_LABEL_DIRECT)));
@@ -674,7 +722,7 @@ gboolean area_edit(area_edit_t *area) {
   /* ------------- center/extent edit ------------------------ */
 
   vbox = gtk_vbox_new(FALSE, 10);
-  table = gtk_table_new(3, 4, FALSE);  // x, y
+  table = gtk_table_new(3, 5, FALSE);  // x, y
   gtk_table_set_col_spacings(GTK_TABLE(table), 10);
   gtk_table_set_row_spacings(GTK_TABLE(table), 5);
 
@@ -728,11 +776,16 @@ gboolean area_edit(area_edit_t *area) {
   label = gtk_label_new(_("(recommended width/height < 2km/1.25mi)"));
   gtk_table_attach_defaults(GTK_TABLE(table), label, 0, 3, 3, 4);
 
+  /* error label */
+  context.extent.error = gtk_label_new("");
+  gtk_widget_modify_fg(context.extent.error, GTK_STATE_NORMAL, &color);
+  gtk_table_attach_defaults(GTK_TABLE(table), context.extent.error, 0, 3, 4, 5);
+  
   gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 0);
   gtk_notebook_append_page(GTK_NOTEBOOK(context.notebook),
 		   vbox, gtk_label_new(_(TAB_LABEL_EXTENT)));
 
-#ifdef USE_HILDON 
+#ifdef HAS_MAEMO_MAPPER
   /* ------------- fetch from maemo mapper ------------------------ */
 
   vbox = gtk_vbox_new(FALSE, 8);
